/*
 * T-Plan Robot Enterprise, automated testing tool.
 * Copyright (C) 2016 T-Plan Limited (http://www.t-plan.com),
 * All rights reserved.
 */
package com.tplan.extent;

import com.tplan.robot.scripting.ScriptingContext;
import java.io.File;

/**
 * Extent report generator interface.
 */
interface ExtentReport {

    /**
     * Key used to store the extent report instance into the current context.
     */
    public static final String CONTEXT_KEY_EXTENT_REPORT_LIST = "CTX_EXTENT_REPORT_LIST";

    /**
     * Start an Extent report.
     *
     * @param context the script context.
     * @param reportFile the report file path (HTML). If the path is relative it
     * will be resolved against the script report directory provided by Robot.
     * @param testName the test name.
     * @param testDesc the test description.
     * @param recordLogs true will record Robot logs to the report.
     */
    void startReport(ScriptingContext context, String file, String testName, String testDesc, String projectName, String mongoHost, int mongoPort, String klovHost, int klovPort, boolean recordLogs);

    /**
     * Flush the report (save it to file).
     */
    void flushReport();

    /**
     * Add an author name to the current test.
     *
     * @param author author name.
     */
    void addAuthor(String author);

    /**
     * Add a system parameter (system info) to the report.
     *
     * @param param parameter name, for example "Environment".
     * @param value parameter value, for example "Windows 7 x64".
     */
    void addSystemInfo(String param, String value);

    /**
     * Add a test category to the current test.
     *
     * @param category a category, for example "Regression".
     */
    void addCategory(String category);

    /**
     * Set the Extent configuration file.
     *
     * @param config the configuration file.
     */
    void setConfiguration(File config);
}
